@@ -17,7 +17,6 @@
 
 namespace H5 {
 
-//! Class PropList provides operations for generic property lists.
 /*! \class PropList
     \brief Class PropList inherits from IdComponent and provides wrappers for
     the HDF5 generic property list.
@@ -75,8 +74,13 @@ class H5_DLLCPP PropList : public IdComponent {
     H5std_string getProperty(const H5std_string &name) const;
 
     // Set a property's value in a property list.
-    void setProperty(const char *name, void *value) const;
     void setProperty(const char *name, const char *charptr) const;
+    void setProperty(const char *name, const void *value) const;
+    void setProperty(const char *name, const H5std_string &strg) const;
+    void setProperty(const H5std_string &name, const void *value) const;
+    void setProperty(const H5std_string &name, const H5std_string &strg) const;
+    // Deprecated after 1.10.1, missing const
+    void setProperty(const char *name, void *value) const;
     void setProperty(const char *name, H5std_string &strg) const;
     void setProperty(const H5std_string &name, void *value) const;
     void setProperty(const H5std_string &name, H5std_string &strg) const;
@@ -88,7 +92,7 @@ class H5_DLLCPP PropList : public IdComponent {
     // Determines whether a property list is a certain class.
     bool isAClass(const PropList &prop_class) const;
 
-    /// Query the existance of a property in a property object.
+    /// Query the existence of a property in a property object.
     bool propExist(const char *name) const;
     bool propExist(const H5std_string &name) const;
 
