@@ -519,11 +519,11 @@ test_generate(void)
 {
     hid_t       fid;
     hsize_t     pal_dims[2] = {256, 3};
-    float      *data        = NULL;
+    float *     data        = NULL;
     int         imax, jmax, kmax;
     int         n_elements;
     float       valex, xmin, xmax, value;
-    FILE       *f         = NULL;
+    FILE *      f         = NULL;
     const char *data_file = H5_get_srcdir_filename(DATA_FILE4);
     int         i;
     int         retval = FAIL;
@@ -650,10 +650,10 @@ test_generate(void)
     HL_TESTING2("make indexed image from land data");
 
     for (i = 0; i < n_elements; i++) {
-        if (data[i] < 0.0f)
+        if (data[i] < 0)
             image_data[i] = 0;
         else
-            image_data[i] = (unsigned char)((255 * data[i]) / xmax);
+            image_data[i] = (unsigned char)((255 * (data[i])) / xmax);
     }
 
     /* make the image */
@@ -671,11 +671,10 @@ test_generate(void)
     HL_TESTING2("make indexed image from sea data");
 
     for (i = 0; i < n_elements; i++) {
-        if (data[i] > 0.0f)
+        if (data[i] > 0)
             image_data[i] = 0;
-        else {
-            image_data[i] = (unsigned char)((255.0f * (data[i] - xmin)) / (xmax - xmin));
-        }
+        else
+            image_data[i] = (unsigned char)((255 * (data[i] - xmin)) / xmin);
     }
 
     /* make the image */
@@ -757,13 +756,13 @@ out:
 
 static int
 read_data(const char *fname, /*IN*/
-          hsize_t    *width, /*OUT*/
-          hsize_t    *height /*OUT*/)
+          hsize_t *   width, /*OUT*/
+          hsize_t *   height /*OUT*/)
 {
     int         i, n;
     int         color_planes;
     char        str[20];
-    FILE       *f = NULL;
+    FILE *      f = NULL;
     int         w, h;
     int         n_elements;
     const char *data_file = H5_get_srcdir_filename(fname);
@@ -876,14 +875,14 @@ out:
 static int
 read_palette(const char *fname, rgb_t *palette, size_t palette_size)
 {
-    FILE        *file;
+    FILE *       file;
     char         buffer[80];
     unsigned     u;
     unsigned int red;
     unsigned int green;
     unsigned int blue;
     unsigned     nentries;
-    const char  *data_file = H5_get_srcdir_filename(fname);
+    const char * data_file = H5_get_srcdir_filename(fname);
 
     /* ensure the given palette is valid */
     if (!palette)
