@@ -1,5 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -185,6 +186,10 @@ enum H5TEST_COLL_CHUNK_API {
 #define TEST_NOT_SIMPLE_OR_SCALAR_DATASPACES            0x010
 #define TEST_NOT_CONTIGUOUS_OR_CHUNKED_DATASET_COMPACT  0x020
 #define TEST_NOT_CONTIGUOUS_OR_CHUNKED_DATASET_EXTERNAL 0x040
+#define TEST_FILTERS                                    0x080
+/* TEST_FILTERS will take place of this after supporting mpio + filter for
+ * H5Dcreate and H5Dwrite */
+#define TEST_FILTERS_READ 0x100
 
 /* Don't erase these lines, they are put here for debugging purposes */
 /*
@@ -213,8 +218,8 @@ typedef int DATATYPE;
 
 /* Shape Same Tests Definitions */
 typedef enum {
-    IND_CONTIG,  /* Independent IO on contiguous datasets */
-    COL_CONTIG,  /* Collective IO on contiguous datasets */
+    IND_CONTIG,  /* Independent IO on contigous datasets */
+    COL_CONTIG,  /* Collective IO on contigous datasets */
     IND_CHUNKED, /* Independent IO on chunked datasets */
     COL_CHUNKED  /* Collective IO on chunked datasets */
 } ShapeSameTestMethods;
@@ -228,9 +233,9 @@ extern int dxfer_coll_type;
 
 /* Test program prototypes */
 void test_plist_ed(void);
+void external_links(void);
 void zero_dim_dset(void);
 void test_file_properties(void);
-void test_invalid_libver_bounds_file_close_assert(void);
 void multiple_dset_write(void);
 void multiple_group_write(void);
 void multiple_group_read(void);
@@ -254,7 +259,6 @@ void none_selection_chunk(void);
 void actual_io_mode_tests(void);
 void no_collective_cause_tests(void);
 void test_chunk_alloc(void);
-void test_chunk_alloc_incr_ser_to_par(void);
 void test_filter_read(void);
 void compact_dataset(void);
 void null_dataset(void);
